==> jc-1.4.0.tar.gz: soot/baf/internal/BIncInst__24LinkedBafLocalBox.h <==
// class soot.baf.internal.BIncInst$LinkedBafLocalBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class ee219f2cd5ff1a45 soot_baf_internal_BIncInst__24LinkedBafLocalBox
// @dep_class c88d7eec5445a3a8 soot_baf_internal_BafLocalBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BafLocalBox

#include "soot/baf/internal/BafLocalBox.h"

#ifndef _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_
#define _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_baf_internal_BIncInst$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object;

typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods;
typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable;
typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype;

// Constructors
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$_init$b9d3ff8ba2014922(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_soot_baf_internal_BIncInst$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$getValue$5c68332c5d4a9bf9(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *);
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$setOtherBox$6d08ef9dbd7c1f27(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *);
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$setValue$f9a819a454867ebc(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$getValue$5c68332c5d4a9bf9;
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$setOtherBox$6d08ef9dbd7c1f27;
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$setValue$f9a819a454867ebc;

// Virtual methods structure
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods {
	struct _jc_object	*(*getValue$5c68332c5d4a9bf9)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *);
	void	(*setOtherBox$6d08ef9dbd7c1f27)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *);
	void	(*setValue$f9a819a454867ebc)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_baf_internal_BafLocalBox$vmethods	soot_baf_internal_BafLocalBox;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
};

// Vtype
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs {
	struct _jc_object	*otherBox;
	struct _jc_soot_baf_internal_BIncInst$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs {
    _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
    _jc_soot_baf_internal_BafLocalBox$sub_refs	soot_baf_internal_BafLocalBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_baf_internal_BafLocalBox$sub_nonrefs	soot_baf_internal_BafLocalBox;
    _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
};

// Object instance structure
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object {
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype	*vtype;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BIncInst__24LinkedBafLocalBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$class_object;

#endif	/* _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BIncInst__24LinkedBafLocalBox.h <==
// class soot.baf.internal.BIncInst$LinkedBafLocalBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class ee219f2cd5ff1a45 soot_baf_internal_BIncInst__24LinkedBafLocalBox
// @dep_class c88d7eec5445a3a8 soot_baf_internal_BafLocalBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_BafLocalBox

#include "soot/baf/internal/BafLocalBox.h"

#ifndef _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_
#define _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_baf_internal_BIncInst$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs;
typedef struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object;

typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods;
typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable;
typedef const struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype;

// Constructors
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$_init$b9d3ff8ba2014922(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_soot_baf_internal_BIncInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$getValue$5c68332c5d4a9bf9(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$setOtherBox$6d08ef9dbd7c1f27(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method$setValue$f9a819a454867ebc(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$getValue$5c68332c5d4a9bf9;
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$setOtherBox$6d08ef9dbd7c1f27;
extern _jc_method _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$method_info$setValue$f9a819a454867ebc;

// Virtual methods structure
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods {
	struct _jc_object	*(*getValue$5c68332c5d4a9bf9)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *) _JC_JCNI_ATTR;
	void	(*setOtherBox$6d08ef9dbd7c1f27)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setValue$f9a819a454867ebc)(_jc_env *, struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_baf_internal_BafLocalBox$vmethods	soot_baf_internal_BafLocalBox;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vmethods	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
};

// Vtype
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs {
	struct _jc_object	*otherBox;
	struct _jc_soot_baf_internal_BIncInst$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs {
    _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_refs	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
    _jc_soot_baf_internal_BafLocalBox$sub_refs	soot_baf_internal_BafLocalBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_baf_internal_BafLocalBox$sub_nonrefs	soot_baf_internal_BafLocalBox;
    _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$sub_nonrefs	soot_baf_internal_BIncInst__24LinkedBafLocalBox;
};

// Object instance structure
struct _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$object {
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype	*vtype;
	_jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$vtype _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BIncInst__24LinkedBafLocalBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BIncInst__24LinkedBafLocalBox$class_object;

#endif	/* _JC_soot_baf_internal_BIncInst__24LinkedBafLocalBox_H_ */
